@@ -101,16 +101,13 @@ var searchData=
   ['urireferencefactory',['UriReferenceFactory',['../servicecom_1_1sun_1_1star_1_1uri_1_1UriReferenceFactory.html',1,'com::sun::star::uri']]],
   ['urischemeparser_5fvnddotsundotstardotexpand',['UriSchemeParser_vndDOTsunDOTstarDOTexpand',['../servicecom_1_1sun_1_1star_1_1uri_1_1UriSchemeParser__vndDOTsunDOTstarDOTexpand.html',1,'com::sun::star::uri']]],
   ['urischemeparser_5fvnddotsundotstardotscript',['UriSchemeParser_vndDOTsunDOTstarDOTscript',['../servicecom_1_1sun_1_1star_1_1uri_1_1UriSchemeParser__vndDOTsunDOTstarDOTscript.html',1,'com::sun::star::uri']]],
-  ['url',['URL',['../structcom_1_1sun_1_1star_1_1util_1_1URL.html',1,'com::sun::star::util']]],
-  ['url',['URL',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1URL.html',1,'com::sun::star::text::textfield']]],
+  ['url',['URL',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1URL.html',1,'URL'],['../structcom_1_1sun_1_1star_1_1util_1_1URL.html',1,'URL']]],
   ['urlauthenticationrequest',['URLAuthenticationRequest',['../exceptioncom_1_1sun_1_1star_1_1ucb_1_1URLAuthenticationRequest.html',1,'com::sun::star::ucb']]],
   ['urlrecord',['UrlRecord',['../structcom_1_1sun_1_1star_1_1task_1_1UrlRecord.html',1,'com::sun::star::task']]],
   ['urltransformer',['URLTransformer',['../servicecom_1_1sun_1_1star_1_1util_1_1URLTransformer.html',1,'com::sun::star::util']]],
   ['urpbridge',['UrpBridge',['../servicecom_1_1sun_1_1star_1_1bridge_1_1UrpBridge.html',1,'com::sun::star::bridge']]],
   ['usebackupexception',['UseBackupException',['../exceptioncom_1_1sun_1_1star_1_1embed_1_1UseBackupException.html',1,'com::sun::star::embed']]],
-  ['user',['User',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1User.html',1,'com::sun::star::text::textfield']]],
-  ['user',['User',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1User.html',1,'com::sun::star::sdbcx']]],
-  ['user',['User',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1User.html',1,'com::sun::star::text::fieldmaster']]],
+  ['user',['User',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1User.html',1,'User'],['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1User.html',1,'User'],['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1User.html',1,'User']]],
   ['userdefinedattributessupplier',['UserDefinedAttributesSupplier',['../servicecom_1_1sun_1_1star_1_1xml_1_1UserDefinedAttributesSupplier.html',1,'com::sun::star::xml']]],
   ['userdefinedindex',['UserDefinedIndex',['../servicecom_1_1sun_1_1star_1_1text_1_1UserDefinedIndex.html',1,'com::sun::star::text']]],
   ['userdescriptor',['UserDescriptor',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1UserDescriptor.html',1,'com::sun::star::sdbcx']]],
